pub struct MemoryStore<V: Clone + Send + Sync + 'static> { /* private fields */ }Expand description
The L1 memory store.
Implementations
Sourceimpl<V: Clone + Send + Sync + 'static> MemoryStore<V>
impl<V: Clone + Send + Sync + 'static> MemoryStore<V>
Sourcepub fn new(max_capacity: Option<u64>, events: Events) -> Self
pub fn new(max_capacity: Option<u64>, events: Events) -> Self
Creates a store with an optional maximum entry capacity (None =
unbounded). events receives an Eviction event
whenever the backend evicts an entry for expiry or capacity (not for our
own explicit removes/updates).
Sourcepub async fn get(&self, key: &str) -> Option<Entry<V>>
pub async fn get(&self, key: &str) -> Option<Entry<V>>
Reads an entry, if present and not physically expired.
Sourcepub async fn remove(&self, key: &str) -> Option<Entry<V>>
pub async fn remove(&self, key: &str) -> Option<Entry<V>>
Removes an entry, returning the previous value if any.
Sourcepub fn invalidate_all(&self)
pub fn invalidate_all(&self)
Invalidates every entry (lazily).
Sourcepub async fn run_pending_tasks(&self)
pub async fn run_pending_tasks(&self)
Forces pending maintenance to run — primarily for deterministic tests.