pub struct CacheRegistry<V: Clone + Send + Sync + 'static> { /* private fields */ }Expand description
A thread-safe registry of named caches of a single value type.
Use this where FusionCache uses keyed/named caches from DI: register a cache under a name once, then resolve it anywhere.
Implementations
Sourceimpl<V: Clone + Send + Sync + 'static> CacheRegistry<V>
impl<V: Clone + Send + Sync + 'static> CacheRegistry<V>